' ========================================================================================
' GdipGetHatchStyle
' ========================================================================================

' SED_PBWIN
#COMPILE EXE
#DIM ALL
#INCLUDE "GDIPLUS.INC"

%IDC_GRAPHIC = 101

' ========================================================================================
' The following example sets up two hatch styles: horiz and current (initialized to
' HatchStyleDiagonalCross). A rectangle that uses horiz as the hatch style is painted.
' Then the GetHatchStyle method is used to get the current hatch style of the brush (which
' at the time is HatchStyleHorizontal). The address of the current HatchStyle object
' (initialized to HatchStyleDiagonalCross) is passed as the return point for the call to
' GdipGetHatchStyle. When the rectangle is painted again, notice that the hatch style is
' again HatchStyleHorizontal (not HatchStyleDiagonalCross). This shows that the call to
' GdipGetHatchStyle was successful.
' ========================================================================================
SUB GDIP_GetHatchStyle (BYVAL hdc AS DWORD)

   LOCAL hStatus AS LONG
   LOCAL pGraphics AS DWORD
   LOCAL pColorBlue AS DWORD
   LOCAL pColorTurquoise AS DWORD
   LOCAL horizStyle AS LONG
   LOCAL currentStyle AS LONG
   LOCAL pBrush AS DWORD
   LOCAL pBrush2 AS DWORD

   hStatus = GdipCreateFromHDC(hdc, pGraphics)

   ' // Set colors.
   pColorBlue = GDIP_ARGB(255, 0, 0, 255)          ' foreground
   pColorTurquoise = GDIP_ARGB(255, 0, 255, 255)   ' background

   ' // Set hatch styles.
   horizStyle = %HatchStyleHorizontal
   currentStyle = %HatchStyleDiagonalCross

   ' // Set and then draw the first hatch style.
   hStatus = GdipCreateHatchBrush(horizStyle, pColorBlue, pColorTurquoise, pBrush)
   hStatus = GdipFillRectangle(pGraphics, pBrush, 20, 20, 100, 50)

   ' // Get the current hatch style of the brush.
   hStatus = GdipGetHatchStyle(pBrush, currentStyle)

   ' // Draw the rectangle again using the current hatch style.
   hStatus = GdipCreateHatchBrush(currentStyle, pColorBlue, pColorTurquoise, pBrush2)
   hStatus = GdipFillRectangle(pGraphics, pBrush, 130, 20, 100, 50)

   ' // Cleanup
   IF pBrush THEN GdipDeleteBrush(pBrush)
   IF pBrush2 THEN GdipDeleteBrush(pBrush2)
   IF pGraphics THEN GdipDeleteGraphics(pGraphics)

END SUB
' ========================================================================================

' ========================================================================================
' Main
' ========================================================================================
FUNCTION WINMAIN (BYVAL hInstance AS DWORD, BYVAL hPrevInstance AS DWORD, BYVAL lpszCmdLine AS ASCIIZ PTR, BYVAL nCmdShow AS LONG) AS LONG

   LOCAL hr AS LONG
   LOCAL hDlg AS DWORD
   LOCAL hdc AS DWORD
   LOCAL token AS DWORD
   LOCAL StartupInput AS GdiplusStartupInput

   ' Initialize GDI+
   StartupInput.GdiplusVersion = 1
   hr = GdiplusStartup(token, StartupInput, BYVAL %NULL)
   IF hr THEN
      MSGBOX "Error initializing GDI+"
      EXIT FUNCTION
   END IF

   ' Create a new dialog
   DIALOG NEW PIXELS, 0, "GdipGetHatchStyle", , , 420, 250, %WS_SYSMENU TO hDlg

   ' Add a graphic control
   CONTROL ADD GRAPHIC, hDlg, %IDC_GRAPHIC,"", 0, 0, 420, 250
   ' Select the drawing target
   GRAPHIC ATTACH hDlg, %IDC_GRAPHIC
   ' Set the foreground and background color
   GRAPHIC COLOR %BLACK, %WHITE
   ' Clear the entire selected graphic window
   GRAPHIC CLEAR
   ' Retrieve the handle of the device context
   GRAPHIC GET DC TO hdc
   ' Draw the graphics
   GDIP_GetHatchStyle hdc

   DIALOG SHOW MODAL hDlg, CALL DlgProc

   ' Shutdown GDI+
   GdiplusShutdown token

END FUNCTION
' ========================================================================================

' ========================================================================================
' Main Dialog procedure
' ========================================================================================
CALLBACK FUNCTION DlgProc() AS LONG

   SELECT CASE CBMSG

      CASE %WM_COMMAND
         SELECT CASE CBCTL
            CASE %IDCANCEL
               IF CBCTLMSG = %BN_CLICKED THEN DIALOG END CBHNDL, 0
         END SELECT

   END SELECT

END FUNCTION
' ========================================================================================
